package deviceStatus

import (
	"fmt"
	"github.com/gogf/gf/database/gredis"
	"github.com/gogf/gf/encoding/gjson"
)

const (
	KeyPrefix   = "status:device:"
	dataExpires = 7200
)

type SplitStatus struct {
	Power      int `json:"power"`
	Mode       int `json:"mode"`
	FanSpeed   int `json:"fan_speed"`
	SetTemp    int `json:"set_temp"`
	EnvTemp    int `json:"env_temp"`
	EnvCo2     int `json:"env_co2"`
	EnvPm25    int `json:"env_pm25"`
	StatusCode int `json:"status_code"`
	AirMode    int `json:"air_mode"`
	AcType     int `json:"ac_type"`
	AirType    int `json:"air_type"`
	HumType    int `json:"hum_type"`
}

type DevStatusManager struct {
	redisClient *gredis.Redis
}

func NewDevStatusManager(host string, port int) *DevStatusManager {
	red := gredis.New(&gredis.Config{
		Host:      host,
		Port:      port,
		Db:        14,
		MaxActive: 100,
	})
	mgr := &DevStatusManager{
		redisClient: red,
	}
	return mgr
}

func (mgr *DevStatusManager) GetDeviceStatus(id string) (*gjson.Json, error) {
	key := KeyPrefix + id
	fmt.Println(key)
	var status SplitStatus
	// get status from redis
	result, err := mgr.redisClient.DoVar("GET", key)
	if err != nil {
		return nil, err
	}
	err = result.Struct(&status)
	return gjson.New(result.String()), nil
}
